{"": "", "Copy terminal content": "Copiar conte\u00fado do terminal", "Done": "Conclu\u00eddo", "Name": "Nome", "Open a new terminal": "Abrir um novo terminal", "Run": "Executar", "Run a command...": "Execute um comando...", "Script": "Script", "Terminals": "Terminais", "Terminate": "Terminar", "stdin data": "stdin data", "Terminal": "Terminal", "Run arbitrary scripts": "Executar scripts arbitr\u00e1rios", "Open shell terminals": "Abrir um novo terminal", "Terminal was closed": "Terminal foi fechado", "You will be redirect to the previous page.": "Voc\u00ea ser\u00e1 redirecionado para a p\u00e1gina anterior.", "Use exit or Ctrl+D to exit terminal.": "Use exit ou Ctrl+D para sair do terminal.", "Starting the script": "Iniciando o script", "Script has finished": "Script finalizado", "Script has failed": "Script falhou", "Could not launch the script": "N\u00e3o foi poss\u00edvel iniciar o script"}