{"": "", "Copy terminal content": "Salin isi terminal", "Done": "Selesai", "Name": "Nama", "Open a new terminal": "Buka terminal baru", "Run": "Menjalankan", "Run a command...": "Jalankan perintah...", "Script": "Naskah", "Terminals": "Terminal", "Terminate": "Mengakhiri", "stdin data": "data stdin", "Terminal": "Terminal", "Run arbitrary scripts": "Jalankan script yang sewenang-wenang", "Open shell terminals": "Buka terminal shell", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}