{"": "", "Copy terminal content": "Copier le contenu du terminal", "Done": "Effectu\u00e9", "Name": "Nom", "Open a new terminal": "Ouvrir un nouveau terminal", "Run": "Ex\u00e9cuter", "Run a command...": "Ex\u00e9cuter une commande...", "Script": "Script", "Terminals": "Terminals", "Terminate": "Terminer", "stdin data": "donn\u00e9es stdin", "Terminal": "Terminal", "Run arbitrary scripts": "Ex\u00e9cuter des scripts arbitraires", "Open shell terminals": "Ouvrir un terminal shell", "Terminal was closed": "Le terminal a \u00e9t\u00e9 ferm\u00e9", "You will be redirect to the previous page.": "Vous serez redirig\u00e9 vers la page pr\u00e9c\u00e9dente.", "Use exit or Ctrl+D to exit terminal.": "Tapez exit ou Ctrl+D pour quitter le terminal.", "Starting the script": "D\u00e9marrage du script", "Script has finished": "L'ex\u00e9cution du script est termin\u00e9", "Script has failed": "L'ex\u00e9cution du script a \u00e9chou\u00e9", "Could not launch the script": "Impossible de lancer le script"}