{"": "", "Copy terminal content": "Copiar contenido de la terminal", "Done": "Finalizado", "Name": "Nombre", "Open a new terminal": "Abrir una nueva terminal", "Run": "Ejecutar", "Run a command...": "Ejecutar un comando...", "Script": "Archivos de comandos", "Terminals": "Terminales", "Terminate": "Finalizar", "stdin data": "entrada de datos est\u00e1ndar", "Terminal": "Terminal", "Run arbitrary scripts": "Ejecutar archivos de comandos arbitrarios", "Open shell terminals": "Abrir terminales shell", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}