{"": "", "Copy terminal content": "Kopiowanie tre\u015bci terminala", "Done": "Wykonane", "Name": "Nazwa", "Open a new terminal": "Otw\u00f3rz nowy terminal", "Run": "Uruchom", "Run a command...": "Uruchom polecenie...", "Script": "Skrypt", "Terminals": "Terminale", "Terminate": "Przerwij", "stdin data": "Dane stdin", "Terminal": "Terminal", "Run arbitrary scripts": "Uruchom dowolne skrypty", "Open shell terminals": "Otw\u00f3rz pow\u0142ok\u0119 terminala", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}