{"": "", "Copy terminal content": "Kopiera terminalinneh\u00e5ll", "Done": "Klar", "Name": "Namn", "Open a new terminal": "\u00d6ppna en ny terminal", "Run": "K\u00f6r", "Run a command...": "K\u00f6r ett kommando...", "Script": "Skript", "Terminals": "Terminaler", "Terminate": "Avsluta", "stdin data": "stdin data", "Terminal": "Terminal", "Run arbitrary scripts": "K\u00f6r godtyckliga skript", "Open shell terminals": "\u00d6ppna skalterminaler", "Terminal was closed": "Terminalen var st\u00e4ngd", "You will be redirect to the previous page.": "Du kommer att omdirigeras till f\u00f6reg\u00e5ende sida.", "Use exit or Ctrl+D to exit terminal.": "Anv\u00e4nd exit eller Ctrl+D f\u00f6r att avsluta terminalen.", "Starting the script": "Startar skriptet", "Script has finished": "Skriptet har avslutats", "Script has failed": "Skriptet misslyckades", "Could not launch the script": "Kunde inte starta skriptet"}