{"": "", "Copy terminal content": "Terminal-Inhalt kopieren", "Done": "Fertig", "Name": "Name", "Open a new terminal": "Neues Terminal \u00f6ffnen", "Run": "Ausf\u00fchren", "Run a command...": "Einen Befehl ausf\u00fchren...", "Script": "Skript", "Terminals": "Terminals", "Terminate": "Beenden", "stdin data": "stdin-Daten", "Terminal": "Terminal", "Run arbitrary scripts": "Beliebige Skripte ausf\u00fchren", "Open shell terminals": "Shell-Terminals \u00f6ffnen", "Terminal was closed": "Terminal wurde geschlossen", "You will be redirect to the previous page.": "Sie werden zur vorherigen Seite weitergeleitet.", "Use exit or Ctrl+D to exit terminal.": "Verwenden Sie exit oder Strg+D, um das Terminal zu verlassen.", "Starting the script": "Skript wird gestartet", "Script has finished": "Skript wurde ausgef\u00fchrt", "Script has failed": "Skriptausf\u00fchrung ist fehlgeschlagen", "Could not launch the script": "Das Skript konnte nicht gestartet werden"}