{"": "", "Copy terminal content": "Terminal inhoud kopi\u00ebren", "Done": "Gereed", "Name": "Naam", "Open a new terminal": "Open een nieuwe terminal", "Run": "Uitvoeren", "Run a command...": "Een opdracht uitvoeren...", "Script": "Script", "Terminals": "Terminals", "Terminate": "Be\u00ebindigen", "stdin data": "stdin-gegevens", "Terminal": "Terminal", "Run arbitrary scripts": "Willekeurige scripts uitvoeren", "Open shell terminals": "Open de Terminal.", "Terminal was closed": "Terminal is gesloten", "You will be redirect to the previous page.": "Je wordt doorverwezen naar de vorige pagina.", "Use exit or Ctrl+D to exit terminal.": "Afsluiten of Ctrl+D gebruiken om de terminal af te sluiten.", "Starting the script": "script starten", "Script has finished": "Script is voltooid", "Script has failed": "Script is mislukt", "Could not launch the script": "Kan het script niet starten"}