{"": "", "Copy terminal content": "Copia il contenuto dal terminale", "Done": "Chiudi", "Name": "Nome", "Open a new terminal": "Apri un nuovo terminale", "Run": "Esegui", "Run a command...": "Esegui un comando...", "Script": "Script", "Terminals": "Terminali", "Terminate": "Termina", "stdin data": "stdin data", "Terminal": "Terminale", "Run arbitrary scripts": "Esegui uno script arbitrario", "Open shell terminals": "Apri un terminale shell", "Terminal was closed": "Il terminale \u00e8 stato chiuso", "You will be redirect to the previous page.": "Sarai reindirizzato alla pagina precedente.", "Use exit or Ctrl+D to exit terminal.": "Usa esci o Ctrl+D per uscire dal terminale.", "Starting the script": "Avviando lo script", "Script has finished": "Script terminato", "Script has failed": "Script fallito", "Could not launch the script": "Impossibile lanciare lo script"}