{"": "", "Copy terminal content": "Kopiraj vsebino terminala", "Done": "Kon\u010dano", "Name": "Ime", "Open a new terminal": "Odpri nov terminal", "Run": "Za\u017eeni", "Run a command...": "Za\u017eeni ukaz...", "Script": "Skripta", "Terminals": "Terminali", "Terminate": "Prekini", "stdin data": "stdin podatki", "Terminal": "Terminal", "Run arbitrary scripts": "Za\u017eeni poljubne skripte", "Open shell terminals": "Odprti terminali lupine", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}