{"": "", "Copy terminal content": "", "Done": "\u1015\u103c\u102e\u1038\u1015\u103c\u102e", "Name": "\u1021\u1019\u100a\u103a", "Open a new terminal": "\u1010\u102c\u1019\u102e\u1014\u101a\u103a \u1021\u101e\u1005\u103a\u1010\u1005\u103a\u1001\u102f \u1016\u103d\u1004\u1037\u103a\u1015\u102b", "Run": "\u101c\u102f\u1015\u103a\u1015\u102b", "Run a command...": "", "Script": "Script", "Terminals": "\u1010\u102c\u1019\u102e\u1014\u101a\u103a\u1019\u103b\u102c\u1038", "Terminate": "", "stdin data": "", "Terminal": "", "Run arbitrary scripts": "", "Open shell terminals": "", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}