{"": "", "Copy terminal content": "Kop\u00edrovat obsah termin\u00e1lu", "Done": "Hotovo", "Name": "Jm\u00e9no", "Open a new terminal": "Otev\u0159\u00edt nov\u00fd termin\u00e1l", "Run": "Spustit", "Run a command...": "Spustit p\u0159\u00edkaz...", "Script": "Skript", "Terminals": "Termin\u00e1ly", "Terminate": "Ukon\u010dit", "stdin data": "data standardn\u00edho vstupu", "Terminal": "Termin\u00e1l", "Run arbitrary scripts": "Spustit libovoln\u00e9 skripty", "Open shell terminals": "Otev\u0159en\u00e9 shell termin\u00e1ly", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}