{"": "", "Copy terminal content": "", "Done": "F\u00e4ts", "Name": "N\u00f3mina", "Open a new terminal": "", "Run": "", "Run a command...": "", "Script": "", "Terminals": "", "Terminate": "", "stdin data": "", "Terminal": "", "Run arbitrary scripts": "", "Open shell terminals": "", "Terminal was closed": "", "You will be redirect to the previous page.": "", "Use exit or Ctrl+D to exit terminal.": "", "Starting the script": "", "Script has finished": "", "Script has failed": "", "Could not launch the script": ""}